@@ -10,13 +10,13 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: asmlibrarian.ml 7188 2005-10-27 09:02:31Z maranget $ *)
+(* $Id: asmlibrarian.ml 10507 2010-06-04 19:16:58Z maranget $ *)
 
 (* Build libraries of .cmx files *)
 
 open Misc
 open Config
-open Compilenv
+open Cmx_format
 
 type error =
     File_not_found of string
@@ -71,4 +71,3 @@ let report_error ppf = function
       fprintf ppf "Cannot find file %s" name
   | Archiver_error name ->
       fprintf ppf "Error while creating the library %s" name
-
