@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: cmmgen.mli 9081 2008-10-14 07:37:28Z maranget $ *)
+(* $Id: cmmgen.mli 10507 2010-06-04 19:16:58Z maranget $ *)
 
 (* Translation from closed lambda to C-- *)
 
@@ -19,14 +19,14 @@ val compunit: int -> Clambda.ulambda -> Cmm.phrase list
 val apply_function: int -> Cmm.phrase
 val send_function: int -> Cmm.phrase
 val curry_function: int -> Cmm.phrase list
-val generic_functions: bool -> Compilenv.unit_infos list -> Cmm.phrase list
+val generic_functions: bool -> Cmx_format.unit_infos list -> Cmm.phrase list
 val entry_point: string list -> Cmm.phrase
 val global_table: string list -> Cmm.phrase
 val reference_symbols: string list -> Cmm.phrase
-val globals_map: (string * Digest.t * Digest.t * string list) list -> 
+val globals_map: (string * Digest.t * Digest.t * string list) list ->
   Cmm.phrase
 val frame_table: string list -> Cmm.phrase
 val data_segment_table: string list -> Cmm.phrase
 val code_segment_table: string list -> Cmm.phrase
 val predef_exception: string -> Cmm.phrase
-val plugin_header: (Compilenv.unit_infos * Digest.t) list -> Cmm.phrase
+val plugin_header: (Cmx_format.unit_infos * Digest.t) list -> Cmm.phrase
