@@ -10,13 +10,14 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: compilenv.ml 9081 2008-10-14 07:37:28Z maranget $ *)
+(* $Id: compilenv.ml 10507 2010-06-04 19:16:58Z maranget $ *)
 
 (* Compilation environments for compilation units *)
 
 open Config
 open Misc
 open Clambda
+open Cmx_format
 
 type error =
     Not_a_unit_info of string
@@ -25,36 +26,6 @@ type error =
 
 exception Error of error
 
-(* Each .o file has a matching .cmx file that provides the following infos
-   on the compilation unit:
-     - list of other units imported, with CRCs of their .cmx files
-     - approximation of the structure implemented
-       (includes descriptions of known functions: arity and direct entry
-        points)
-     - list of currying functions and application functions needed
-   The .cmx file contains these infos (as an externed record) plus a CRC
-   of these infos *)
-
-type unit_infos =
-  { mutable ui_name: string;                    (* Name of unit implemented *)
-    mutable ui_symbol: string;            (* Prefix for symbols *)
-    mutable ui_defines: string list;      (* Unit and sub-units implemented *)
-    mutable ui_imports_cmi: (string * Digest.t) list; (* Interfaces imported *)
-    mutable ui_imports_cmx: (string * Digest.t) list; (* Infos imported *)
-    mutable ui_approx: value_approximation;     (* Approx of the structure *)
-    mutable ui_curry_fun: int list;             (* Currying functions needed *)
-    mutable ui_apply_fun: int list;             (* Apply functions needed *)
-    mutable ui_send_fun: int list;              (* Send functions needed *)
-    mutable ui_force_link: bool }               (* Always linked *)
-
-(* Each .a library has a matching .cmxa file that provides the following
-   infos on the library: *)
-
-type library_infos =
-  { lib_units: (unit_infos * Digest.t) list;  (* List of unit infos w/ CRCs *)
-    lib_ccobjs: string list;            (* C object files needed *)
-    lib_ccopts: string list }           (* Extra opts to C compiler *)
-
 let global_infos_table =
   (Hashtbl.create 17 : (string, unit_infos option) Hashtbl.t)
 
@@ -179,7 +150,7 @@ let record_global_approx_toplevel id =
 let global_approx id =
   if Ident.is_predef_exn id then Value_unknown
   else try Hashtbl.find toplevel_approx (Ident.name id)
-  with Not_found -> 
+  with Not_found ->
     match get_global_info id with
       | None -> Value_unknown
       | Some ui -> ui.ui_approx
@@ -240,4 +211,3 @@ let report_error ppf = function
       fprintf ppf "Corrupted compilation unit description@ %s" filename
   | Illegal_renaming(modname, filename) ->
       fprintf ppf "%s@ contains the description for unit@ %s" filename modname
-
