@@ -10,41 +10,12 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: compilenv.mli 9081 2008-10-14 07:37:28Z maranget $ *)
+(* $Id: compilenv.mli 10507 2010-06-04 19:16:58Z maranget $ *)
 
 (* Compilation environments for compilation units *)
 
 open Clambda
-
-(* Each .o file has a matching .cmx file that provides the following infos
-   on the compilation unit:
-     - list of other units imported, with CRCs of their .cmx files
-     - approximation of the structure implemented
-       (includes descriptions of known functions: arity and direct entry
-        points)
-     - list of currying functions and application functions needed
-   The .cmx file contains these infos (as an externed record) plus a CRC
-   of these infos *)
-
-type unit_infos =
-  { mutable ui_name: string;                    (* Name of unit implemented *)
-    mutable ui_symbol: string;            (* Prefix for symbols *)
-    mutable ui_defines: string list;      (* Unit and sub-units implemented *)
-    mutable ui_imports_cmi: (string * Digest.t) list; (* Interfaces imported *)
-    mutable ui_imports_cmx: (string * Digest.t) list; (* Infos imported *)
-    mutable ui_approx: value_approximation;     (* Approx of the structure *)
-    mutable ui_curry_fun: int list;             (* Currying functions needed *)
-    mutable ui_apply_fun: int list;             (* Apply functions needed *)
-    mutable ui_send_fun: int list;              (* Send functions needed *)
-    mutable ui_force_link: bool }               (* Always linked *)
-
-(* Each .a library has a matching .cmxa file that provides the following
-   infos on the library: *)
-
-type library_infos =
-  { lib_units: (unit_infos * Digest.t) list;  (* List of unit infos w/ CRCs *)
-    lib_ccobjs: string list;            (* C object files needed *)
-    lib_ccopts: string list }           (* Extra opts to C compiler *)
+open Cmx_format
 
 val reset: ?packname:string -> string -> unit
         (* Reset the environment and record the name of the unit being
@@ -106,5 +77,3 @@ type error =
 exception Error of error
 
 val report_error: Format.formatter -> error -> unit
-
-
