@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: meta.mli 7192 2005-10-27 09:14:16Z maranget $ *)
+(* $Id: meta.mli 10506 2010-06-04 19:16:52Z maranget $ *)
 
 (* To control the runtime system and bytecode interpreter *)
 
@@ -18,11 +18,12 @@ external global_data : unit -> Obj.t array = "caml_get_global_data"
 external realloc_global_data : int -> unit = "caml_realloc_global"
 external static_alloc : int -> string = "caml_static_alloc"
 external static_free : string -> unit = "caml_static_free"
-external static_release_bytecode : string -> int -> unit = "caml_static_release_bytecode" 
+external static_release_bytecode : string -> int -> unit
+                                 = "caml_static_release_bytecode"
 external static_resize : string -> int -> string = "caml_static_resize"
 type closure = unit -> Obj.t
 external reify_bytecode : string -> int -> closure = "caml_reify_bytecode"
 external invoke_traced_function : Obj.t -> Obj.t -> Obj.t -> Obj.t
                                 = "caml_invoke_traced_function"
 external get_section_table : unit -> (string * Obj.t) list
-                                = "caml_get_section_table"
+                           = "caml_get_section_table"
