@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: finalise.c 9301 2009-06-19 07:11:12Z maranget $ */
+/* $Id: finalise.c 10505 2010-06-04 19:16:46Z maranget $ */
 
 /* Handling of finalised values. */
 
@@ -122,6 +122,7 @@ static int running_finalisation_function = 0;
 void caml_final_do_calls (void)
 {
   struct final f;
+  value res;
 
   if (running_finalisation_function) return;
 
@@ -139,8 +140,9 @@ void caml_final_do_calls (void)
       -- to_do_hd->size;
       f = to_do_hd->item[to_do_hd->size];
       running_finalisation_function = 1;
-      caml_callback (f.fun, f.val + f.offset);   /* FIXME PR#4742 */
+      res = caml_callback_exn (f.fun, f.val + f.offset);
       running_finalisation_function = 0;
+      if (Is_exception_result (res)) caml_raise (Extract_exception (res));
     }
     caml_gc_message (0x80, "Done calling finalisation functions.\n", 0);
   }
