@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: int64_emul.h 9301 2009-06-19 07:11:12Z maranget $ */
+/* $Id: int64_emul.h 10505 2010-06-04 19:16:46Z maranget $ */
 
 /* Software emulation of 64-bit integer arithmetic, for C compilers
    that do not support it.  */
@@ -97,7 +97,7 @@ static int64 I64_mul(int64 x, int64 y)
 
 #define I64_is_zero(x) (((x).l | (x).h) == 0)
 #define I64_is_negative(x) ((int32) (x).h < 0)
-#define I64_is_min_int(x) ((x).l == 0 && (x).h = 0x80000000U)
+#define I64_is_min_int(x) ((x).l == 0 && (x).h == 0x80000000U)
 #define I64_is_minus_one(x) (((x).l & (x).h) == 0xFFFFFFFFU)
 
 /* Bitwise operations */
