@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: ints.c 10505 2010-06-04 19:16:46Z maranget $ */
+/* $Id: ints.c 11113 2011-07-07 14:32:00Z maranget $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -614,7 +614,7 @@ static void nativeint_serialize(value v, uintnat * wsize_32,
 {
   intnat l = Nativeint_val(v);
 #ifdef ARCH_SIXTYFOUR
-  if (l <= 0x7FFFFFFFL && l >= -0x80000000L) {
+  if (l >= -((intnat)1 << 31) && l < ((intnat)1 << 31)) {
     caml_serialize_int_1(1);
     caml_serialize_int_4((int32) l);
   } else {
