@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: stacks.h 7192 2005-10-27 09:14:16Z maranget $ */
+/* $Id: stacks.h 10505 2010-06-04 19:16:46Z maranget $ */
 
 /* structure of the stacks */
 
@@ -36,6 +36,8 @@ CAMLextern value * caml_trap_barrier;
 void caml_init_stack (uintnat init_max_size);
 void caml_realloc_stack (asize_t required_size);
 void caml_change_max_stack_size (uintnat new_max_size);
+uintnat caml_stack_usage (void);
 
+CAMLextern uintnat (*caml_stack_usage_hook)(void);
 
 #endif /* CAML_STACKS_H */
