@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: sys.c 8113 2007-03-23 09:01:11Z maranget $ */
+/* $Id: sys.c 11113 2011-07-07 14:32:00Z maranget $ */
 
 /* Basic system calls */
 
@@ -138,12 +138,14 @@ CAMLprim value caml_sys_open(value path, value vflags, value vperm)
   /* open on a named FIFO can block (PR#1533) */
   caml_enter_blocking_section();
   fd = open(p, flags, perm);
+  /* fcntl on a fd can block (PR#5069)*/
+#if defined(F_SETFD) && defined(FD_CLOEXEC)
+  if (fd != -1)
+    fcntl(fd, F_SETFD, FD_CLOEXEC);
+#endif
   caml_leave_blocking_section();
   caml_stat_free(p);
   if (fd == -1) caml_sys_error(path);
-#if defined(F_SETFD) && defined(FD_CLOEXEC)
-  fcntl(fd, F_SETFD, FD_CLOEXEC);
-#endif
   CAMLreturn(Val_long(fd));
 }
 
