@@ -10,7 +10,7 @@
 ;(*                                                                     *)
 ;(***********************************************************************)
 
-;(* $Id: caml-emacs.el 6857 2005-05-04 20:30:00Z habouzit $ *)
+;(* $Id: caml-emacs.el 11113 2011-07-07 14:32:00Z maranget $ *)
 
 ;; for caml-help.el
 (defalias 'caml-info-other-window 'info-other-window)
@@ -39,5 +39,8 @@
          (or (member 'drag modifiers)
              (member 'click modifiers)))))
 
+(if (fboundp 'string-to-number)
+   (defalias 'caml-string-to-int 'string-to-number)
+ (defalias 'caml-string-to-int 'string-to-int))
 
 (provide 'caml-emacs)
