@@ -59,7 +59,7 @@
     . font-lock-builtin-face)
 ;control
    (,(concat "[|#&]\\|->\\|"
-             (regexp-opt '("do" "done" "dowto" "else" "for" "if" "ignore"
+             (regexp-opt '("do" "done" "downto" "else" "for" "if" "ignore"
                            "lazy" "match" "new" "reply"
 			   "spawn" "then" "to" "try"
                            "when" "while" "with")
