@@ -10,7 +10,7 @@
 ;(*                                                                     *)
 ;(***********************************************************************)
 
-;(* $Id: caml-xemacs.el 6857 2005-05-04 20:30:00Z habouzit $ *)
+;(* $Id: caml-xemacs.el 11113 2011-07-07 14:32:00Z maranget $ *)
 
 (require 'overlay)
 
@@ -50,4 +50,8 @@
   (and (button-release-event-p event)
        (equal (event-button original) (event-button event))))
 
+(if (fboundp 'string-to-number)
+   (defalias 'caml-string-to-int 'string-to-number)
+ (defalias 'caml-string-to-int 'string-to-int))
+
 (provide 'caml-xemacs)
