@@ -10,7 +10,7 @@
 ;(*                                                                     *)
 ;(***********************************************************************)
 
-;(* $Id: caml.el 9322 2009-08-21 08:39:33Z maranget $ *)
+;(* $Id: caml.el 11113 2011-07-07 14:32:00Z maranget $ *)
 
 ;;; caml.el --- O'Caml code editing commands for Emacs
 ;; Luc Maranget, January 2008. A few jocaml additions.
@@ -815,8 +815,9 @@ from an error message produced by camlc.")
 (defvar caml-error-overlay nil)
 (defvar caml-next-error-skip-warnings-flag nil)
 
-(defun caml-string-to-int (x)
-  (if (fboundp 'string-to-number) (string-to-number x) (string-to-int x)))
+(if (fboundp 'string-to-number)
+   (defalias 'caml-string-to-int 'string-to-number)
+ (defalias 'caml-string-to-int 'string-to-int))
 
 ;;itz 04-21-96 somebody didn't get the documentation for next-error
 ;;right. When the optional argument is a number n, it should move
@@ -1168,7 +1169,7 @@ Used to distinguish it from toplevel let construct.")
   (concat
    "\\<\\(and"
    (if caml-is-jocaml "\\|or" "")
-   "\\|do\\(ne\\)?\\|e\\(lse\\|nd\\)\\|in\\|t\\(hen\\|o\\)"
+   "\\<\\(and\\|do\\(ne\\|wnto\\)?\\|e\\(lse\\|nd\\)\\|in\\|t\\(hen\\|o\\)"
    "\\|with\\)\\>\\|[^[|]|")
   "Regexp used in caml mode for skipping back over nested blocks.")
 
@@ -1184,6 +1185,7 @@ Used to distinguish it from toplevel let construct.")
     ("else" . caml-find-else-match)
     ("then" . caml-find-then-match)
     ("to" . caml-find-done-match)
+    ("downto" . caml-find-done-match)
     ("do" . caml-find-done-match)
     ("and" . caml-find-and-match))))
     (if caml-is-jocaml (cons '("or" . caml-find-and-match) aux) aux))
@@ -1611,7 +1613,7 @@ Does not preserve point."
 
 (defconst caml-leading-kwops-regexp
   (concat
-   "\\<\\(and\\|do\\(ne\\)?\\|e\\(lse\\|nd\\)\\|in"
+   "\\<\\(and\\|do\\(ne\\|wnto\\)?\\|e\\(lse\\|nd\\)\\|in"
    (if caml-is-jocaml "\\|or" "")
    "\\|t\\(hen\\|o\\)\\|with\\)\\>\\|[]|})]")
 
@@ -1628,6 +1630,7 @@ Does not preserve point."
 	  ("in" caml-in-extra-indent 2)
 	  ("then" caml-then-extra-indent 3)
 	  ("to" caml-to-extra-indent 0)
+	  ("downto" caml-to-extra-indent 0)
 	  ("with" caml-with-extra-indent 2)
 	  ("|" caml-|-extra-indent 2)
 	  ("]" caml-rb-extra-indent 0)
