@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: join.mli 8726 2007-12-18 09:59:36Z maranget $ *)
+(* $Id: join.mli 10494 2010-06-04 07:48:53Z maranget $ *)
 
 (** The JoCaml core library.
 
@@ -130,6 +130,9 @@ module Ns : sig
   val of_site : Site.t -> t
   (** Get remote name service by site identity. *)
 
+  val to_site : t -> Site.t
+  (** Converse operation *)
+
   val there : Unix.sockaddr -> t
   (** Get remote name service by socket address.
       Basically, [there addr] is [of_site (Site.there addr)]. *)
