@@ -10,13 +10,19 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: joinProc.ml 8755 2008-01-07 14:33:24Z maranget $ *)
+(* $Id: joinProc.ml 10612 2010-06-29 15:47:12Z maranget $ *)
 
 open Unix
 
+let try_set_close_on_exec fd =
+  try set_close_on_exec fd; true with Invalid_argument _ -> false
+
 let open_proc cmd args input output err toclose =
+  let cloexec = List.for_all try_set_close_on_exec toclose in
   match fork () with
   | 0 ->
+      (* Safer to use close on exec, (ocaml bug PR#2715) *)
+      if not cloexec then List.iter close toclose;
       if input <> stdin then begin
 	dup2 input stdin; close input
       end;
@@ -26,7 +32,6 @@ let open_proc cmd args input output err toclose =
       if err <> stderr then begin
 	dup2 err stderr; close err
       end;
-      List.iter close toclose ;
       begin try Unix.execvp cmd args
       with _ -> exit 127 end
   | id -> id
@@ -38,15 +43,15 @@ let command cmd args =
 let open_in cmd args =
   let in_read, in_write = pipe() in
   let id = open_proc cmd args stdin in_write stderr [in_read] in
-  let inchan = in_channel_of_descr in_read in
   close in_write ;
+  let inchan = in_channel_of_descr in_read in
   id, inchan
 
 let open_out cmd args =
   let out_read, out_write = pipe() in
   let id = open_proc cmd args out_read stdout stderr [out_write] in
-  let outchan = out_channel_of_descr out_write in
   close out_read;
+  let outchan = out_channel_of_descr out_write in
   id, outchan
 
 let open_in_out cmd args =
@@ -54,12 +59,13 @@ let open_in_out cmd args =
   let out_read, out_write = pipe() in
   let id =
     open_proc cmd args out_read in_write stderr [in_read; out_write] in
-  let inchan = in_channel_of_descr in_read in
-  let outchan = out_channel_of_descr out_write in
   close out_read;
   close in_write;
+  let inchan = in_channel_of_descr in_read in
+  let outchan = out_channel_of_descr out_write in
   id, (inchan, outchan)
 
+
 let open_full cmd args =
   let in_read, in_write = pipe() in
   let out_read, out_write = pipe() in
@@ -67,11 +73,13 @@ let open_full cmd args =
   let id =
     open_proc cmd args out_read in_write err_write
       [in_read; out_write; err_read] in
-  let inchan = in_channel_of_descr in_read in
-  let outchan = out_channel_of_descr out_write in
-  let errchan = in_channel_of_descr err_read in
+(* Critical section in open_fork, from fork system call *)
   close out_read;
   close in_write;
   close err_write;
+(* End critical section *)
+  let inchan = in_channel_of_descr in_read in
+  let outchan = out_channel_of_descr out_write in
+  let errchan = in_channel_of_descr err_read in
   id, (inchan, outchan, errchan)
 
