@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: big_int.ml 10509 2010-06-04 19:17:18Z maranget $ *)
+(* $Id: big_int.ml 11113 2011-07-07 14:32:00Z maranget $ *)
 
 open Int_misc
 open Nat
@@ -701,7 +701,9 @@ let shift_right_towards_zero_big_int bi n =
         let tmp = create_nat 1 in
         shift_right_nat res 0 size_res tmp 0 nbits
       end;
-      { sign = bi.sign; abs_value = res }
+      if is_zero_nat res 0 size_res
+      then zero_big_int
+      else { sign = bi.sign; abs_value = res }
     end
   end
 
