@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: join_link.ml 8296 2007-06-01 07:46:53Z maranget $ *)
+(* $Id: join_link.ml 10588 2010-06-17 16:37:18Z maranget $ *)
 
 (*DEBUG*)open Join_debug
 (*DEBUG*)open Printf
@@ -42,12 +42,12 @@ let output_string { outc = outc } v =
   try
     output_string outc v
   with
-  | Sys_error _ as e ->
-(*DEBUG*)debug1 "OUTPUT_STRING"  "failed on %s" (Join_misc.exn_to_string e) ;
+  | Sys_error _ as _e ->
+(*DEBUG*)debug1 "OUTPUT_STRING"  "failed on %s" (Join_misc.exn_to_string _e) ;
       raise Failed
-  | e ->
+  | _e ->
 (*DEBUG*)debug0 "FATAL OUTPUT_STRING"
-(*DEBUG*)  "failed on %s" (Join_misc.exn_to_string e) ;   
+(*DEBUG*)  "failed on %s" (Join_misc.exn_to_string _e) ;   
       assert false
  
 
@@ -55,9 +55,9 @@ let flush { outc = outc } =
   try
      flush outc
   with
-  | Sys_error _ as e ->
+  | Sys_error _ as _e ->
 (*DEBUG*)debug1 "FLUSH"
-(*DEBUG*)  "failed on %s" (Join_misc.exn_to_string e) ;
+(*DEBUG*)  "failed on %s" (Join_misc.exn_to_string _e) ;
       raise Failed
   | e ->
 (*DEBUG*)debug0 "FATAL FLUSH"
@@ -69,9 +69,9 @@ let really_input { inc = inc } buff ofs len =
   try
     really_input inc buff ofs len
   with
-  | End_of_file|Sys_error _ as e ->
+  | End_of_file|Sys_error _ as _e ->
 (*DEBUG*)debug1 "REALLY INPUT"
-(*DEBUG*)  "failed on %s" (Join_misc.exn_to_string e) ;
+(*DEBUG*)  "failed on %s" (Join_misc.exn_to_string _e) ;
       raise Failed
   | e ->
 (*DEBUG*)debug0 "FATAL REALLY INPUT"
@@ -82,9 +82,9 @@ let close {fd=fd} =
   try
     Unix.close fd
   with
-  | Unix.Unix_error (Unix.EBADF,_,_) as e ->
+  | Unix.Unix_error (Unix.EBADF,_,_) as _e ->
 (*DEBUG*)debug1 "LINK CLOSE"
-(*DEBUG*)  "failed on %s" (Join_misc.exn_to_string e) ;
+(*DEBUG*)  "failed on %s" (Join_misc.exn_to_string _e) ;
       raise Failed
   | e ->
 (*DEBUG*)debug0 "IO ERROR IN LINK CLOSE"
