@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: join_prim.ml 8296 2007-06-01 07:46:53Z maranget $ *)
+(* $Id: join_prim.ml 10933 2011-01-28 16:06:24Z maranget $ *)
 
 open Join_types
 open Printf
@@ -301,9 +301,12 @@ let tail_send_async chan a = match chan with
 
 let space_id_of_chan chan =
   let stub = match chan with Async(stub,_)|Alone(stub,_) -> stub in
-  match stub.stub_tag with
-  | Local -> Join_space.here
-  | Remote -> (Obj.magic stub.stub_val : space_id)
+  let id =
+    match stub.stub_tag with
+    | Local -> Join_space.here
+    | Remote -> (Obj.magic stub.stub_val : space_id) in
+(*DEBUG*)debug0 "SPACE_ID" "%s-%i-%f" id.host (fst id.uniq) (snd id.uniq);
+  id
 
 (*********************)
 (* Synchronous sends *)
