@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: pervasives.ml 8113 2007-03-23 09:01:11Z maranget $ *)
+(* $Id: pervasives.ml 10611 2010-06-29 13:52:11Z maranget $ *)
 
 (* Same as ../../stdlib/pervasives.ml, except that I/O functions have
    been redefined to not block the whole process, but only the calling
@@ -55,6 +55,7 @@ external (||) : bool -> bool -> bool = "%sequor"
 (* Integer operations *)
 
 external (~-) : int -> int = "%negint"
+external (~+) : int -> int = "%identity"
 external succ : int -> int = "%succint"
 external pred : int -> int = "%predint"
 external (+) : int -> int -> int = "%addint"
@@ -81,12 +82,14 @@ let max_int = min_int - 1
 (* Floating-point operations *)
 
 external (~-.) : float -> float = "%negfloat"
+external (~+.) : float -> float = "%identity"
 external (+.) : float -> float -> float = "%addfloat"
 external (-.) : float -> float -> float = "%subfloat"
 external ( *. ) : float -> float -> float = "%mulfloat"
 external (/.) : float -> float -> float = "%divfloat"
 external ( ** ) : float -> float -> float = "caml_power_float" "pow" "float"
 external exp : float -> float = "caml_exp_float" "exp" "float"
+external expm1 : float -> float = "caml_expm1_float" "caml_expm1" "float"
 external acos : float -> float = "caml_acos_float" "acos" "float"
 external asin : float -> float = "caml_asin_float" "asin" "float"
 external atan : float -> float = "caml_atan_float" "atan" "float"
@@ -95,6 +98,7 @@ external cos : float -> float = "caml_cos_float" "cos" "float"
 external cosh : float -> float = "caml_cosh_float" "cosh" "float"
 external log : float -> float = "caml_log_float" "log" "float"
 external log10 : float -> float = "caml_log10_float" "log10" "float"
+external log1p : float -> float = "caml_log1p_float" "caml_log1p" "float"
 external sin : float -> float = "caml_sin_float" "sin" "float"
 external sinh : float -> float = "caml_sinh_float" "sinh" "float"
 external sqrt : float -> float = "caml_sqrt_float" "sqrt" "float"
@@ -268,10 +272,10 @@ let rec flush oc =
       wait_outchan oc (-1); false in
   if success then () else flush oc
 
-external out_channels_list : unit -> out_channel list 
+external out_channels_list : unit -> out_channel list
                            = "caml_ml_out_channels_list"
 
-let flush_all () = 
+let flush_all () =
   let rec iter = function
       [] -> ()
     | a::l ->
@@ -296,7 +300,7 @@ let rec unsafe_output oc buf pos len =
     unsafe_output oc buf (pos + written) (len - written)
   end
 
-external output_char_blocking : out_channel -> char -> unit 
+external output_char_blocking : out_channel -> char -> unit
                               = "caml_ml_output_char"
 external output_byte_blocking : out_channel -> int -> unit
                               = "caml_ml_output_char"
@@ -311,7 +315,7 @@ let output_string oc s =
   unsafe_output oc s 0 (string_length s)
 
 let output oc s ofs len =
-  if ofs < 0 || len < 0 || ofs > string_length s - len 
+  if ofs < 0 || len < 0 || ofs > string_length s - len
   then invalid_arg "output"
   else unsafe_output oc s ofs len
 
@@ -329,7 +333,7 @@ let output_binary_int oc n =
   output_byte oc (n asr 8);
   output_byte oc n
 
-external marshal_to_string : 'a -> unit list -> string 
+external marshal_to_string : 'a -> unit list -> string
                            = "caml_output_value_to_string"
 
 let output_value oc v = output_string oc (marshal_to_string v [])
@@ -492,7 +496,7 @@ module LargeFile =
   end
 
 (* Formats *)
-type ('a, 'b, 'c, 'd) format4 = ('a, 'b, 'c, 'c, 'c, 'd) format6 
+type ('a, 'b, 'c, 'd) format4 = ('a, 'b, 'c, 'c, 'c, 'd) format6
 
 type ('a, 'b, 'c) format = ('a, 'b, 'c, 'c) format4
 
@@ -510,7 +514,8 @@ let (( ^^ ) :
       ('f, 'b, 'c, 'e, 'g, 'h) format6 ->
       ('a, 'b, 'c, 'd, 'g, 'h) format6) =
   fun fmt1 fmt2 ->
-    string_to_format (format_to_string fmt1 ^ format_to_string fmt2);;
+    string_to_format (format_to_string fmt1 ^ "%," ^ format_to_string fmt2)
+;;
 
 let string_of_format fmt =
   let s = format_to_string fmt in
@@ -519,7 +524,6 @@ let string_of_format fmt =
   string_blit s 0 r 0 l;
   r
 
-
 (* Miscellaneous *)
 
 external sys_exit : int -> 'a = "caml_sys_exit"
