@@ -11,9 +11,10 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: fork.c 4255 2002-01-16 16:32:52Z peskine $ */
+/* $Id: fork.c 10509 2010-06-04 19:17:18Z maranget $ */
 
 #include <mlvalues.h>
+#include <debugger.h>
 #include "unixsupport.h"
 
 CAMLprim value unix_fork(value unit)
@@ -21,6 +22,9 @@ CAMLprim value unix_fork(value unit)
   int ret;
   ret = fork();
   if (ret == -1) uerror("fork", Nothing);
+  if (caml_debugger_in_use)
+    if ((caml_debugger_fork_mode && ret == 0) ||
+        (!caml_debugger_fork_mode && ret != 0))
+      caml_debugger_cleanup_fork();
   return Val_int(ret);
 }
-
