@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: asttypes.mli 7197 2005-10-27 11:14:16Z maranget $ *)
+(* $Id: asttypes.mli 10518 2010-06-04 19:19:28Z maranget $ *)
 
 (* Auxiliary a.s.t. types used by parsetree and typedtree. *)
 
@@ -33,4 +33,8 @@ type mutable_flag = Immutable | Mutable
 
 type virtual_flag = Virtual | Concrete
 
+type override_flag = Override | Fresh
+
+type closed_flag = Closed | Open
+
 type label = string
