@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: syntaxerr.ml 9081 2008-10-14 07:37:28Z maranget $ *)
+(* $Id: syntaxerr.ml 10518 2010-06-04 19:19:28Z maranget $ *)
 
 (* Auxiliary type for reporting syntax errors *)
 
@@ -18,6 +18,7 @@ open Format
 
 type error =
     Unclosed of Location.t * string * Location.t * string
+  | Applicative_path of Location.t
   | Other of Location.t
 
 exception Error of error
@@ -35,5 +36,8 @@ let report_error ppf = function
         fprintf ppf "%aThis '%s' might be unmatched"
           Location.print_error opening_loc opening
       end
+  | Applicative_path loc ->
+      fprintf ppf "%aSyntax error: applicative paths of the form F(X).t are not supported when the option -no-app-func is set."
+        Location.print_error loc
   | Other loc ->
       fprintf ppf "%aSyntax error" Location.print_error loc
