@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: arg.ml 9081 2008-10-14 07:37:28Z maranget $ *)
+(* $Id: arg.ml 11113 2011-07-07 14:32:00Z maranget $ *)
 
 type key = string
 type doc = string
@@ -90,10 +90,14 @@ let usage_b buf speclist errmsg =
   List.iter (print_spec buf) (add_help speclist);
 ;;
 
-let usage speclist errmsg =
+let usage_string speclist errmsg =
   let b = Buffer.create 200 in
   usage_b b speclist errmsg;
-  eprintf "%s" (Buffer.contents b);
+  Buffer.contents b;
+;;
+
+let usage speclist errmsg =
+  eprintf "%s" (usage_string speclist errmsg);
 ;;
 
 let current = ref 0;;
