@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: arg.mli 9081 2008-10-14 07:37:28Z maranget $ *)
+(* $Id: arg.mli 11113 2011-07-07 14:32:00Z maranget $ *)
 
 (** Parsing of command line arguments.
 
@@ -79,7 +79,7 @@ val parse :
     as their arguments appear on the command line.
 
     If an error occurs, [Arg.parse] exits the program, after printing
-    an error message as follows:
+    to standard error an error message as follows:
 -   The reason for the error: unknown option, invalid or missing argument, etc.
 -   [usage_msg]
 -   The list of options, each followed by the corresponding [doc] string.
@@ -88,9 +88,9 @@ val parse :
     [-], include for example [("-", String anon_fun, doc)] in [speclist].
 
     By default, [parse] recognizes two unit options, [-help] and [--help],
-    which will display [usage_msg] and the list of options, and exit
-    the program.  You can override this behaviour by specifying your
-    own [-help] and [--help] options in [speclist].
+    which will print to standard output [usage_msg] and the list of
+    options, and exit the program.  You can override this behaviour
+    by specifying your own [-help] and [--help] options in [speclist].
 *)
 
 val parse_argv : ?current: int ref -> string array ->
@@ -115,11 +115,15 @@ exception Bad of string
     [Arg.Bad] is also raised by [Arg.parse_argv] in case of an error. *)
 
 val usage : (key * spec * doc) list -> usage_msg -> unit
-(** [Arg.usage speclist usage_msg] prints an error message including
-    the list of valid options.  This is the same message that
-    {!Arg.parse} prints in case of error.
+(** [Arg.usage speclist usage_msg] prints to standard error
+    an error message that includes the list of valid options.  This is
+    the same message that {!Arg.parse} prints in case of error.
     [speclist] and [usage_msg] are the same as for [Arg.parse]. *)
 
+val usage_string : (key * spec * doc) list -> usage_msg -> string
+(** Returns the message that would have been printed by {!Arg.usage},
+    if provided with the same parameters. *)
+
 val align: (key * spec * doc) list -> (key * spec * doc) list;;
 (** Align the documentation strings by inserting spaces at the first
     space, according to the length of the keyword.  Use a
