@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: buffer.mli 9590 2010-01-25 14:52:00Z maranget $ *)
+(* $Id: buffer.mli 10510 2010-06-04 19:17:45Z maranget $ *)
 
 (** Extensible string buffers.
 
@@ -55,7 +55,9 @@ val blit : t -> int -> string -> int -> int -> unit
 
    Raise [Invalid_argument] if [srcoff] and [len] do not designate a valid
    substring of [src], or if [dstoff] and [len] do not designate a valid
-   substring of [dst]. *)
+   substring of [dst].
+   @since 3.11.2
+*)
 
 val nth : t -> int -> char
 (** get the n-th character of the buffer. Raise [Invalid_argument] if
