@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: printf.ml 10510 2010-06-04 19:17:45Z maranget $ *)
+(* $Id: printf.ml 11113 2011-07-07 14:32:00Z maranget $ *)
 
 external format_float: string -> float -> string
   = "caml_format_float"
@@ -106,6 +106,7 @@ let pad_string pad_char p neg s i len =
   then String.blit s i res 0 len
   else String.blit s i res (p - len) len;
   res
+;;
 
 (* Format a string given a %s format, e.g. %40s or %-20s.
    To do ?: ignore other flags (#, +, etc). *)
@@ -196,7 +197,8 @@ let sub_format incomplete_format bad_conversion_format conv fmt i =
 ;;
 
 let sub_format_for_printf conv =
-  sub_format incomplete_format bad_conversion_format conv;;
+  sub_format incomplete_format bad_conversion_format conv
+;;
 
 let iter_on_format_args fmt add_conv add_char =
 
@@ -307,7 +309,7 @@ let ac_of_format fmt =
 
 let count_arguments_of_format fmt =
   let ac = ac_of_format fmt in
-  (* For printing only regular arguments have to be counted. *)
+  (* For printing, only the regular arguments have to be counted. *)
   ac.ac_rglr
 ;;
 
@@ -376,7 +378,7 @@ type positional_specification =
    Note that this is optimized for the regular case, i.e. no positional
    parameter, since in this case we juste ``return'' the constant
    [Spec_none]; in case we have a positional parameter, we ``return'' a
-   [Spec_index] [positional_specification] which a bit more costly.
+   [Spec_index] [positional_specification] which is a bit more costly.
 
    Note also that we do not support [*$] specifications, since this would
    lead to type checking problems: a [*$] positional specification means
@@ -663,9 +665,13 @@ let ksprintf k =
   mkprintf true get_buff Buffer.add_char Buffer.add_string ignore (get_cont k)
 ;;
 
+let sprintf fmt = ksprintf (fun s -> s) fmt;;
+
+(* Obsolete and deprecated. *)
 let kprintf = ksprintf;;
 
-let sprintf fmt = ksprintf (fun s -> s) fmt;;
+(* For Caml system internal use only: needed to implement modules [Format]
+  and [Scanf]. *)
 
 module CamlinternalPr = struct
 
