@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: random.mli 8113 2007-03-23 09:01:11Z maranget $ *)
+(* $Id: random.mli 10510 2010-06-04 19:17:45Z maranget $ *)
 
 (** Pseudo-random number generators (PRNG). *)
 
@@ -29,7 +29,10 @@ val self_init : unit -> unit
    in a system-dependent way. *)
 
 val bits : unit -> int
-(** Return 30 random bits in a nonnegative integer. *)
+(** Return 30 random bits in a nonnegative integer.
+    @before 3.12.0 used a different algorithm (affects all the following
+                   functions)
+*)
 
 val int : int -> int
 (** [Random.int bound] returns a random integer between 0 (inclusive)
