@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: genprintval.ml 9081 2008-10-14 07:37:28Z maranget $ *)
+(* $Id: genprintval.ml 10515 2010-06-04 19:18:31Z maranget $ *)
 
 (* To print values *)
 
@@ -321,6 +321,8 @@ module Make(O : OBJ)(EVP : EVALPATH with type value = O.t) = struct
           | Tunivar ->
               Oval_stuff "<poly>"
           | Tproc _ -> assert false
+          | Tpackage _ ->
+              Oval_stuff "<module>"
         end
 
       and tree_of_val_list start depth obj ty_list =
