@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: opttoploop.ml 9081 2008-10-14 07:37:28Z maranget $ *)
+(* $Id: opttoploop.ml 10515 2010-06-04 19:18:31Z maranget $ *)
 
 (* The interactive toplevel loop *)
 
@@ -333,7 +333,7 @@ let first_line = ref true
 let got_eof = ref false;;
 
 let read_input_default prompt buffer len =
-  output_string stdout prompt; flush stdout;
+  output_string Pervasives.stdout prompt; flush Pervasives.stdout;
   let i = ref 0 in
   try
     while true do
