@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: toploop.ml 9081 2008-10-14 07:37:28Z maranget $ *)
+(* $Id: toploop.ml 10515 2010-06-04 19:18:31Z maranget $ *)
 
 (* The interactive toplevel loop *)
 
@@ -322,12 +322,12 @@ let first_line = ref true
 let got_eof = ref false;;
 
 let read_input_default prompt buffer len =
-  output_string stdout prompt; flush stdout;
+  output_string Pervasives.stdout prompt; flush Pervasives.stdout;
   let i = ref 0 in
   try
     while true do
       if !i >= len then raise Exit;
-      let c = input_char stdin in
+      let c = input_char Pervasives.stdin in
       buffer.[!i] <- c;
       incr i;
       if c = '\n' then raise Exit;
