@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: env.ml 10508 2010-06-04 19:17:06Z maranget $ *)
+(* $Id: env.ml 11113 2011-07-07 14:32:00Z maranget $ *)
 
 (* Environment handling *)
 
@@ -896,4 +896,4 @@ let report_error ppf = function
   | Need_recursive_types(import, export) ->
       fprintf ppf
         "@[<hov>Unit %s imports from %s, which uses recursive types.@ %s@]"
-        import export "The compilation flag -rectypes is required"
+        export import "The compilation flag -rectypes is required"
