@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: ident.ml 7205 2005-10-27 16:29:22Z maranget $ *)
+(* $Id: ident.ml 10508 2010-06-04 19:17:06Z maranget $ *)
 
 open Format
 
@@ -63,7 +63,7 @@ let set_current_time t = currentstamp := max !currentstamp t
 
 let reinit_level = ref (-1)
 
-let reinit () = 
+let reinit () =
   if !reinit_level < 0
   then reinit_level := !currentstamp
   else currentstamp := !reinit_level
@@ -182,3 +182,9 @@ let rec keys_aux stack accu = function
       keys_aux (l :: stack) (k.ident :: accu) r
 
 let keys tbl = keys_aux [] [] tbl
+
+let rec map f = function
+  | Empty -> Empty
+  | Node (l, k, r, h) ->
+      Node (map f l, { k with data = f k.data ; }, map f r, h)
+
