@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: predef.ml 9081 2008-10-14 07:37:28Z maranget $ *)
+(* $Id: predef.ml 10508 2010-06-04 19:17:06Z maranget $ *)
 
 (* Predefined type constructors (with special typing rules in typecore) *)
 
@@ -103,7 +103,7 @@ let build_initial_env add_type add_exception empty_env =
      type_manifest = None;
      type_variance = []}
   and decl_unit =
-    {type_params = []; 
+    {type_params = [];
      type_arity = 0;
      type_kind = Type_variant(["()", []]);
      type_private = Public;
@@ -208,3 +208,9 @@ let builtin_values =
        ident_failure; ident_not_found; ident_sys_error; ident_end_of_file;
        ident_division_by_zero; ident_sys_blocked_io;
        ident_assert_failure; ident_undefined_recursive_module ]
+
+(* Start non-predef identifiers at 1000.  This way, more predefs can
+   be defined in this file (above!) without breaking .cmi
+   compatibility. *)
+
+let _ = Ident.set_current_time 999 
