@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: types.mli 9081 2008-10-14 07:37:28Z maranget $ *)
+(* $Id: types.mli 10508 2010-06-04 19:17:06Z maranget $ *)
 
 (* Representation of types and declarations *)
 
@@ -38,7 +38,10 @@ and type_desc =
   | Tpoly of type_expr * type_expr list
 (*>JOCAML*)
   | Tproc of kont_locs
+(*<JOCAML*)
+  | Tpackage of Path.t * string list * type_expr list
 
+(*>JOCAML*)
 and kont_locs = (Ident.t * Location.t) list
 (*<JOCAML*)
 
@@ -96,8 +99,7 @@ and value_kind =
   | Val_prim of Primitive.description   (* Primitive *)
   | Val_ivar of mutable_flag * string   (* Instance variable (mutable ?) *)
   | Val_self of (Ident.t * type_expr) Meths.t ref *
-                (Ident.t * Asttypes.mutable_flag *
-                 Asttypes.virtual_flag * type_expr) Vars.t ref *
+                (Ident.t * mutable_flag * virtual_flag * type_expr) Vars.t ref *
                 string * type_expr
                                         (* Self *)
   | Val_anc of (string * Ident.t) list * string
@@ -129,7 +131,8 @@ and constructor_tag =
 (* Record label descriptions *)
 
 type label_description =
-  { lbl_res: type_expr;                 (* Type of the result *)
+  { lbl_name: string;                   (* Short name *)
+    lbl_res: type_expr;                 (* Type of the result *)
     lbl_arg: type_expr;                 (* Type of the argument *)
     lbl_mut: mutable_flag;              (* Is this a mutable field? *)
     lbl_pos: int;                       (* Position in block *)
@@ -177,8 +180,7 @@ type class_type =
 
 and class_signature =
   { cty_self: type_expr;
-    cty_vars:
-      (Asttypes.mutable_flag * Asttypes.virtual_flag * type_expr) Vars.t;
+    cty_vars: (mutable_flag * virtual_flag * type_expr) Vars.t;
     cty_concr: Concr.t;
     cty_inher: (Path.t * type_expr list) list }
 
