@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: clflags.mli 9158 2008-12-12 16:38:05Z maranget $ *)
+(* $Id: clflags.mli 10513 2010-06-04 19:18:10Z maranget $ *)
 
 val objfiles : string list ref
 val ccobjs : string list ref
@@ -42,6 +42,8 @@ val use_prims : string ref
 val use_runtime : string ref
 val principal : bool ref
 val recursive_types : bool ref
+val strict_sequence : bool ref
+val applicative_functors : bool ref
 val make_runtime : bool ref
 val gprofile : bool ref
 val c_compiler : string option ref
