@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: config.mli 9081 2008-10-14 07:37:28Z maranget $ *)
+(* $Id: config.mli 10513 2010-06-04 19:18:10Z maranget $ *)
 
 (* System configuration *)
 
@@ -31,12 +31,12 @@ val ccomp_type: string
                "msvc" (Microsoft Visual C++)
                "mrc" (Macintosh MPW) *)
 val bytecomp_c_compiler: string
-        (* The C compiler to use for compiling C files 
+        (* The C compiler to use for compiling C files
            with the bytecode compiler *)
 val bytecomp_c_libraries: string
         (* The C libraries to link with custom runtimes *)
 val native_c_compiler: string
-        (* The C compiler to use for compiling C files 
+        (* The C compiler to use for compiling C files
            with the native-code compiler *)
 val native_c_libraries: string
         (* The C libraries to link with native-code programs *)
@@ -76,6 +76,8 @@ val ast_intf_magic_number: string
         (* Magic number for file holding an interface syntax tree *)
 val ast_impl_magic_number: string
         (* Magic number for file holding an implementation syntax tree *)
+val cmxs_magic_number: string
+        (* Magic number for dynamically-loadable plugins *)
 
 val max_tag: int
         (* Biggest tag that can be stored in the header of a regular block. *)
